@@ -7,17 +7,19 @@ def aggregation_insol(energy_normalized, insolation, frequency='D'):
 
     Parameters
     ----------
-    energy_normalized : pd.Series
+    energy_normalized : pandas.Series
         Normalized energy time series
-    insolation : pd.Series
+    insolation : pandas.Series
         Time series of insolation associated with each `energy_normalized`
         point
-    frequency : Pandas offset string, default 'D'
-        Target frequency at which to aggregate
+    frequency : str or pandas.tseries.offsets.DateOffset
+        Pandas frequency specification at which to aggregate. Default is daily aggregation.
+        For more information see
+        https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#dateoffset-objects
 
     Returns
     -------
-    aggregated : pd.Series
+    aggregated : pandas.Series
         Insolation weighted average, aggregated at frequency
     '''
     aggregated = (insolation * energy_normalized).resample(frequency).sum() / \
