@@ -2,22 +2,23 @@
 
 import numpy as np
 import pandas as pd
-import joblib
 import os
 import warnings
 from numbers import Number
 import rdtools
+import xgboost as xgb
 
 # Load in the XGBoost clipping model using joblib.
 xgboost_clipping_model = None
-model_path = (os.path.dirname(__file__)) + \
-                             "/models/xgboost_clipping_model.dat"
+model_path = os.path.join(os.path.dirname(__file__),
+                          "models", "xgboost_clipping_model.json")
 
 
 def _load_xgboost_clipping_model():
     global xgboost_clipping_model
     if xgboost_clipping_model is None:
-        xgboost_clipping_model = joblib.load(model_path)
+        xgboost_clipping_model = xgb.XGBClassifier()
+        xgboost_clipping_model.load_model(model_path)
     return xgboost_clipping_model
 
 
